Mean of a sparse_numeric vector
mean-sparse_numeric-method.RdComputes the mean of the full dense vector, treating all missing positions as zeros.
Usage
# S4 method for class 'sparse_numeric'
mean(x, ...)mean-sparse_numeric-method.RdComputes the mean of the full dense vector, treating all missing positions as zeros.
# S4 method for class 'sparse_numeric'
mean(x, ...)