Sparse numeric vector S4 class
sparse_numeric-class.RdRepresents a sparse numeric vector by storing only the non-zero values, their positions, and the full length of the underlying dense vector.
sparse_numeric-class.RdRepresents a sparse numeric vector by storing only the non-zero values, their positions, and the full length of the underlying dense vector.